=====
obsea
=====

Obsea metamorphoses Ocean-Bottom Seismometers (OBS) into watchful observers of the Oceans. Sensing infrasound, OBSs can record marine mammal vocalizes, ship traffic noise, iceberg activity and more at very long rages (~100 km). This package aims at automatically recognizing and localizing acoustical sources that can be recorded by OBSs transforming this latter into an efficient acoustic passive sonar.

Documentation can be found at: https://obsea.readthedocs.io/en/latest/

Related publications:

    Trabattoni, A., Barruol, G., Dreo, R., Boudraa, A. O., & Fontaine, F. R. (2019). Orienting and locating ocean-bottom seismometers from ship noise analysis. Geophysical Journal International, ggz519. https://doi.org/10.1093/gji/ggz519

    Trabattoni, A., Barruol, G., Dréo, R., & Boudraa, A. (2023). Ship detection and tracking from single ocean-bottom seismic and hydroacoustic stations. The Journal of the Acoustical Society of America, 153(1), 260–273. https://doi.org/10.1121/10.0016810
